Deployer

Struct Deployer 

pub struct Deployer { /* private fields */ }
Struct that keeps track of the deployment and undeployment process of multiple symlinks.

We keep track of all created symlinks, as well as all symlinks where the creation or deletion failed due to insufficient permissions. In case of missing permissions, you can then use Deployer::try_run_elevated() to retry the operation with elevated privileges.

Implementations

Source

impl Deployer

pub fn new() -> Self

pub fn failed_creations(&self) -> &Vec<(PathBuf, PathBuf)>

pub fn failed_deletions(&self) -> &Vec<PathBuf>

Create a symlink from at the path link pointing to the original file.

Remove a symlink from at the path link pointing to the original file.

Set up a symlink from the given link_path to the given actual_path, recursively. Also takes the egg_root dir, to ensure we can safely delete any stale symlinks on the way there.

Requires all paths to be absolute, will panic otherwise.

This means:

  • If link_path exists and is a file, abort
  • If link_path exists and is a symlink into the egg dir, remove the symlink and then continue.
  • If actual_path is a file, symlink.
  • If actual_path is a directory that does not exist in link_path, symlink it.
  • If actual_path is a directory that already exists in link_path, recurse into it and symlink_recursive actual_paths children.
pub fn try_run_elevated(self) -> Result<()>

Retry running symlink creation and deletion with root priviledges.