pub struct Deployer { /* private fields */ }Expand description
Struct that keeps track of the deployment and undeployment process of multiple symlinks.
We keep track of all created symlinks, as well as all symlinks where the creation or deletion failed due to insufficient permissions.
In case of missing permissions, you can then use Deployer::try_run_elevated() to retry the operation with elevated privileges.
Implementations
Sourceimpl Deployer
impl Deployer
pub fn new() -> Self
pub fn created_symlinks(&self) -> &Vec<PathBuf>
pub fn failed_creations(&self) -> &Vec<(PathBuf, PathBuf)>
pub fn failed_deletions(&self) -> &Vec<PathBuf>
pub fn add_created_symlink(&mut self, link_path: PathBuf)
Sourcepub fn create_symlink(
&mut self,
original: impl AsRef<Path>,
link: impl AsRef<Path>,
) -> Result<()>
pub fn create_symlink( &mut self, original: impl AsRef<Path>, link: impl AsRef<Path>, ) -> Result<()>
Create a symlink from at the path link pointing to the original file.
Sourcepub fn delete_symlink(&mut self, path: impl AsRef<Path>) -> Result<()>
pub fn delete_symlink(&mut self, path: impl AsRef<Path>) -> Result<()>
Remove a symlink from at the path link pointing to the original file.
Sourcepub fn symlink_recursive(
&mut self,
egg_root: impl AsRef<Path>,
actual_path: impl AsRef<Path>,
link_path: &impl AsRef<Path>,
) -> Result<()>
pub fn symlink_recursive( &mut self, egg_root: impl AsRef<Path>, actual_path: impl AsRef<Path>, link_path: &impl AsRef<Path>, ) -> Result<()>
Set up a symlink from the given link_path to the given actual_path, recursively.
Also takes the egg_root dir, to ensure we can safely delete any stale symlinks on the way there.
Requires all paths to be absolute, will panic otherwise.
This means:
- If
link_pathexists and is a file, abort - If
link_pathexists and is a symlink into the egg dir, remove the symlink and then continue. - If
actual_pathis a file, symlink. - If
actual_pathis a directory that does not exist inlink_path, symlink it. - If
actual_pathis a directory that already exists inlink_path, recurse into it andsymlink_recursiveactual_paths children.
pub fn remove_symlink_recursive( &mut self, actual_path: impl AsRef<Path>, link_path: &impl AsRef<Path>, ) -> Result<()>
Sourcepub fn try_run_elevated(self) -> Result<()>
pub fn try_run_elevated(self) -> Result<()>
Retry running symlink creation and deletion with root priviledges.